netapp_ontap.models.snapmirror_relationship_policy API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.snapmirror_relationship_policy`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SnapmirrorRelationshipPolicySchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SnapmirrorRelationshipPolicy object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the snapmirror_relationship_policy.

  `name GET POST PATCH`

    The name field of the snapmirror_relationship_policy.

    Example: Asynchronous

  `type GET`

    The type field of the snapmirror_relationship_policy.

    Valid choices:

    - async
    - sync
  `uuid GET POST PATCH`

    The uuid field of the snapmirror_relationship_policy.

    Example: 4ea7a442-86d1-11e0-ae1c-123478563412